@@ -52,6 +52,7 @@ exports.freeCheck = {
 	var i = 0, 
 	max = license.licenseFragments.length, 
 	item;
+
 	for (; i < max; i++) {
 	    item = license.licenseFragments[i];
 	    item.regex = patternUtils.removeNonalpha(item.text);
@@ -107,17 +108,13 @@ exports.freeCheck = {
 		max = list[license].licenseFragments.length;
 		for (i = 0;i < max; i++) {
 
-		    if (frag[i].type !== LAZY ||
-			simpleStorage.storage['nolazy'] === 'false' ||
-			simpleStorage.storage['nolazy'] == undefined) {
-
 			if (frag[i].regex.test(strippedComment)) {
-
+                            
 			    return list[license].licenseName;
 
 			}
 
-		    }
+
 
 		}
 	    }
