@@ -41,12 +41,6 @@ const prefChange = require("addon_management/prefchange");
 // set whitelist at startup.
 prefChange.init();
 
-// script list for those 
-var scriptList = require("ui/script_list");
-var panelRemovedScripts = scriptList.rejectedScriptsList;
-var panelAcceptedScripts = scriptList.acceptedScriptsList; 
-
-
 var allowedRef = require("http_observer/allowed_referrers").allowedReferrers;
 
 var urlHandler = require("url_handler/url_handler");
@@ -54,51 +48,35 @@ var urlHandler = require("url_handler/url_handler");
 var widgetIsOn = false;
 
 var uiInfo = require("ui/ui_info");
-
-// remove script entries from tabs
-// that are closed.
-uiInfo.clearScriptsFromClosedTab();
+var scriptPanel = require("ui/script_panel.js");
 
 var panelContent = function () {
 
     let panel = this;
-    var urlData, message, externalEntries, 
-        externalScripts, url, urlTabIndex, tabData;
+    var message, externalEntries, 
+        externalScripts, urlTabIndex, tabData;
 
     tabs.activeTab.attach({
-        contentScriptFile: [data.url('third_party/jquery-src.js')],
+        contentScriptFile: [data.url('third_party/jquery-src.js'),
+                            data.url('script_detector/script_detector.js')],
         contentScriptWhen: 'ready',
 
 	onMessage: function (respData) {
 	    // complain content script
-	    if (typeof data === 'object') { 
-		handleTabResponse(panel, respData);
-	    } else {
-		panel.postMessage(respData);
-	    }
+            //console.log("Message received", JSON.stringify(respData));
+            var url = urlHandler.removeFragment(tabs.activeTab.url);
+            
+	    panel.postMessage({'pageURL': url, 
+                               'urlData': scriptPanel.addScriptsToPanelList(tabs.activeTab.url, respData),
+                              'isAllowed': allowedRef.urlInAllowedReferrers(url)});
 	}
+        
+        
     });
 
 
-    url = urlHandler.removeFragment(tabs.activeTab.url);
-    
-    // contains external scripts removed at download time.
-    urlData = removedScripts.getScripts(url);
 
-    // contains all the other scripts (that used domHandler).
-    tabData = { 
-	'removed': panelRemovedScripts[url],
-	'accepted': panelAcceptedScripts[url]
-    };
 
-    if (urlData) {
-	tabData.removed.concat(urlData);
-    }
-
-    message = {'urlData': tabData, 
-	       'pageURL': url,
-	       'isAllowed': allowedRef.urlInAllowedReferrers(url)};
-    this.postMessage(message);
 };
 
 // page mod was here.
@@ -133,15 +111,10 @@ var widget = widgets.Widget({
     panel: mainPanel,
     contentURL: data.url('widget/images/librejs.png'),
     contentScriptWhen: 'end',
-    contentScriptFile: data.url('widget/widget.js')
+    contentScriptFile: [data.url('widget/widget.js')]
 });
 
 
-/*widget.port.on('right-click', function() {
-    prefs.prefpanel.show();
-});*/
-
-
 mainPanel.port.on('complainButtonClicked', function () {
     mainPanel.hide();
 });
@@ -149,7 +122,6 @@ mainPanel.port.on('complainButtonClicked', function () {
 mainPanel.port.on('allowAllClicked', function (url) {
     url = urlHandler.removeFragment(url);
     allowedRef.addPage(url);
-    panelRemovedScripts[url] = [];
     tabs.activeTab.reload();
 });
 
@@ -159,7 +131,6 @@ mainPanel.port.on('disallowAllClicked', function (url) {
     //console.log('before clear, url is in allowedRef', allowedRef.urlInAllowedReferrers(url));
     allowedRef.clearSinglePageEntry(url);
     //console.log('after clear, url is in allowedRef', allowedRef.urlInAllowedReferrers(url));
-    panelRemovedScripts[url] = [];
     mainPanel.hide();
     tabs.activeTab.reload(); 
 });
