@@ -29,12 +29,6 @@ var urlHandler = require("url_handler/url_handler");
 
 var pageWorker = require("page-worker");
 
-var scriptList = require("ui/script_list");
-
-
-var panelRemovedScripts = scriptList.rejectedScriptsList;
-var panelAcceptedScripts = scriptList.acceptedScriptsList; 
-
 // contain list of recently found contact links or email addresses.
 var contactList = {};
 
@@ -56,8 +50,6 @@ const IDENTICA_LINK_FOUND = 'identicaLinkFound';
 const PHONE_NUMBER_FOUND = 'phoneNumberFound';
 const SNAIL_ADDRESS_FOUND = 'snailAddressFound';
 
-
-
 /**
  * main pageMod.
  * Find blocked script in all pages being opened.
@@ -120,93 +112,6 @@ var foundInContactList = function (url) {
 
 };
 
-
-/**
- * addScriptsToPanelList
- *
- * Looks for scripts that are either valid or flagged with libreJS
- * 
- */ 
-var addScriptsToPanelList = function (worker, respData) {
-
-    // use url. remove fragment.
-    var url = urlHandler.removeFragment(worker.tab.url);
-    var contents, i;
-
-    // set script lists as empty arrays if 
-    // they don't exist
-    setScriptArrays(url);
-
-    for (i = 0; i < respData.value.blocked.length; i++) {
-
-	// if external script only.
-	pathToUrl(respData.value.blocked[i], url);
-
-	panelRemovedScripts[url].push(respData.value.blocked[i]);
-
-    }
-    
-
-
-    for (i = 0; i < respData.value.accepted.length; i++) {
-
-	// if external script only.
-	pathToUrl(respData.value.accepted[i], url);
-
-	panelAcceptedScripts[url].push(respData.value.accepted[i]);
-
-    }
-
-};
-
-var setScriptArrays = function (index) {
-    if (panelRemovedScripts[index] == null) {
-	panelRemovedScripts[index] = [];
-    }
-    if (panelAcceptedScripts[index] == null) {
-	panelAcceptedScripts[index] = [];
-    }  
-};
-
-/**
- * clearScriptsFromClosedTab
- * 
- * Whenever a tab is closed, clear the script
- * arrays corresponding to it.
- * 
- */
-exports.clearScriptsFromClosedTab = function () {
-
-    var tabs = require("tabs");
-
-    // use url as property. remove fragment.
-
-
-    var resetScripts = function (tab) {
-	var url = urlHandler.removeFragment(tab.url);
-	panelRemovedScripts[url] = [];
-	panelAcceptedScripts[url] = [];
-    };
-
-
-    tabs.on('ready', function (tab) {
-		resetScripts(tab);
-	    });
-    
-};
-
-/**
- * pathToUrl
- * 
- * convert a relative path to a url.
- * 
- */
-var pathToUrl = function (scriptEntry, url) {
-    if (scriptEntry.inline === false) {
-	scriptEntry.url = urlHandler.resolve(url, scriptEntry.url);
-    }
-};
-
 /**
  * tabProcess
  * Find blocked/accepted scripts, prepare
@@ -226,8 +131,6 @@ var tabProcess = function (worker) {
 
     //console.log('pagemod triggered');
 
-    worker.postMessage({'event': 'tabProcess'});
-
     // send local path to complain button graphic.
     worker.postMessage({'event': 'assets-uri', 'value':  data.url('assets/')});
     worker.postMessage({'event': 'page-url', 'value': modUrl});
@@ -247,15 +150,7 @@ var tabProcess = function (worker) {
 	    }
 	});
 
-	// display list of blocked/allowed scripts.
-	if (respData.event === 'scriptsFetched') {
-	    // add scripts to list.
-	    //console.log('script fetched for', modUrl);
-	    addScriptsToPanelList(worker, respData);
-	}
-
-
-	else if (respData.contact != undefined) {
+	if (respData.contact != undefined) {
 	    // pass the message to the complaint display panel.
 	    worker.postMessage(respData);	
 	}
